@@ -25,56 +25,49 @@ class ListJobGroupsRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'OutboundBot', '2019-12-26', 'ListJobGroups','outboundbot')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AsyncQuery(self):
+	def get_AsyncQuery(self): # Boolean
 		return self.get_query_params().get('AsyncQuery')
 
-	def set_AsyncQuery(self,AsyncQuery):
-		self.add_query_param('AsyncQuery',AsyncQuery)
-
-	def get_SearchText(self):
+	def set_AsyncQuery(self, AsyncQuery):  # Boolean
+		self.add_query_param('AsyncQuery', AsyncQuery)
+	def get_SearchText(self): # String
 		return self.get_query_params().get('SearchText')
 
-	def set_SearchText(self,SearchText):
-		self.add_query_param('SearchText',SearchText)
-
-	def get_EndTime(self):
+	def set_SearchText(self, SearchText):  # String
+		self.add_query_param('SearchText', SearchText)
+	def get_EndTime(self): # Long
 		return self.get_query_params().get('EndTime')
 
-	def set_EndTime(self,EndTime):
-		self.add_query_param('EndTime',EndTime)
-
-	def get_StartTime(self):
+	def set_EndTime(self, EndTime):  # Long
+		self.add_query_param('EndTime', EndTime)
+	def get_StartTime(self): # Long
 		return self.get_query_params().get('StartTime')
 
-	def set_StartTime(self,StartTime):
-		self.add_query_param('StartTime',StartTime)
-
-	def get_PageNumber(self):
+	def set_StartTime(self, StartTime):  # Long
+		self.add_query_param('StartTime', StartTime)
+	def get_PageNumber(self): # Integer
 		return self.get_query_params().get('PageNumber')
 
-	def set_PageNumber(self,PageNumber):
-		self.add_query_param('PageNumber',PageNumber)
-
-	def get_InstanceId(self):
+	def set_PageNumber(self, PageNumber):  # Integer
+		self.add_query_param('PageNumber', PageNumber)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
-
-	def get_JobGroupStatusFilter(self):
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_JobGroupStatusFilter(self): # String
 		return self.get_query_params().get('JobGroupStatusFilter')
 
-	def set_JobGroupStatusFilter(self,JobGroupStatusFilter):
-		self.add_query_param('JobGroupStatusFilter',JobGroupStatusFilter)
-
-	def get_PageSize(self):
+	def set_JobGroupStatusFilter(self, JobGroupStatusFilter):  # String
+		self.add_query_param('JobGroupStatusFilter', JobGroupStatusFilter)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
\ No newline at end of file
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
