@@ -25,40 +25,35 @@ class ModifyInstanceRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'OutboundBot', '2019-12-26', 'ModifyInstance','outboundbot')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_MaxConcurrentConversation(self):
+	def get_MaxConcurrentConversation(self): # Integer
 		return self.get_query_params().get('MaxConcurrentConversation')
 
-	def set_MaxConcurrentConversation(self,MaxConcurrentConversation):
-		self.add_query_param('MaxConcurrentConversation',MaxConcurrentConversation)
-
-	def get_CallingNumbers(self):
+	def set_MaxConcurrentConversation(self, MaxConcurrentConversation):  # Integer
+		self.add_query_param('MaxConcurrentConversation', MaxConcurrentConversation)
+	def get_CallingNumbers(self): # RepeatList
 		return self.get_query_params().get('CallingNumber')
 
-	def set_CallingNumbers(self, CallingNumbers):
-		for depth1 in range(len(CallingNumbers)):
-			if CallingNumbers[depth1] is not None:
-				self.add_query_param('CallingNumber.' + str(depth1 + 1) , CallingNumbers[depth1])
-
-	def get_InstanceId(self):
+	def set_CallingNumbers(self, CallingNumber):  # RepeatList
+		for depth1 in range(len(CallingNumber)):
+			self.add_query_param('CallingNumber.' + str(depth1 + 1), CallingNumber[depth1])
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
-
-	def get_InstanceName(self):
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_InstanceName(self): # String
 		return self.get_query_params().get('InstanceName')
 
-	def set_InstanceName(self,InstanceName):
-		self.add_query_param('InstanceName',InstanceName)
-
-	def get_InstanceDescription(self):
+	def set_InstanceName(self, InstanceName):  # String
+		self.add_query_param('InstanceName', InstanceName)
+	def get_InstanceDescription(self): # String
 		return self.get_query_params().get('InstanceDescription')
 
-	def set_InstanceDescription(self,InstanceDescription):
-		self.add_query_param('InstanceDescription',InstanceDescription)
\ No newline at end of file
+	def set_InstanceDescription(self, InstanceDescription):  # String
+		self.add_query_param('InstanceDescription', InstanceDescription)
